import pkg_resources

from scriptaculous import prototype, scriptaculous_js

from turbogears import startup
from turbogears.widgets import CSSLink, JSLink, Widget, WidgetDescription, \
                               register_static_directory, JSSource, \
                               js_location, set_with_self

static_dir = pkg_resources.resource_filename("lightbox",
                                         "static")
register_static_directory("lightbox", static_dir)

lightbox_js = JSLink("lightbox", "javascript/lightbox.js")
lightbox_css = CSSLink("lightbox", "css/lightbox.css", media="screen")

class CorrectPath(JSSource):
    register = False
    template = """<script type="text/javascript">
    var fileLoadingImage = "${static}images/loading.gif";		
    var fileBottomNavCloseImage = "${static}images/close.gif";
</script>
"""
    def __init__(self):
        super(CorrectPath, self).__init__(
            "fileLoadingImage = images/loading.gif")

    def update_params(self, d):
        super(CorrectPath, self).update_params(d)
        d["static"] = "/%stg_widgets/lightbox/" % (startup.webpath)
    
    retrieve_javascript = set_with_self


class Lightbox(Widget):
    """Creates a Lightbox photo viewer. The value should be the URL of the
    main image to display."""
    javascript = [prototype, scriptaculous_js, lightbox_js, CorrectPath()]
    css = [lightbox_css]
    
    params = ["thumb_url", "thumb_width", "thumb_height"]
    params_doc = dict(value="URL of the full-size image",
        thumb_url="URL of the thumbnail",
        thumb_width="Thumbnail width",
        thumb_height="Thumbnail height")
    
    template = """<a href="${value}" rel="lightbox"><img src="${thumb_url}" width="${thumb_width}" height="${thumb_height}" border="0"/></a>
    """

class LightboxDesc(WidgetDescription):
    for_widget = Lightbox()
    
    template = """<div>${for_widget.display(static + "images/image-1.jpg", thumb_url=static + "images/thumb-1.jpg", thumb_width=100, thumb_height=40)}</div>"""
    
    show_separately = True
    
    def update_params(self, d):
        super(LightboxDesc, self).update_params(d)
        d["static"] = "/%stg_widgets/lightbox/" % (startup.webpath)
        